conops.config.communications
===========================

.. automodule:: conops.config.communications
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Communications System Configuration
-----------------------------------

The communications module provides configuration classes for spacecraft
communications systems, including band capabilities, antenna pointing,
and data rates.

Classes
^^^^^^^

.. autoclass:: conops.config.communications.BandCapability
   :members:
   :show-inheritance:

.. autoclass:: conops.config.communications.AntennaPointing
   :members:
   :show-inheritance:

.. autoclass:: conops.config.communications.CommunicationsSystem
   :members:
   :show-inheritance:

Enums
^^^^^

.. autoclass:: conops.config.communications.AntennaType
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: conops.config.communications.Polarization
   :members:
   :undoc-members:
   :show-inheritance:
